==> fastor_app_ui_widget-0.0.66.tar.gz: lib/resource/state/FastorStateManagement.dart <==

import 'package:flutter/material.dart';

/// Manage the state of the application
///
/// Get current state just call method "FastorStateManagement.instance().getCurrentState()"
///  it's return state of map
///
/// To can use this library must to make all pages use class "PageTemplate"
class FastorStateManagement {

  //---------------------------------------------------------------- varaible

   static Map<String, State> _mapState = Map();


  //--------------------------------------------------------------- single tone

  FastorStateManagement._();

  static bool _isSync = false;

  ///single tone design pattern
  static FastorStateManagement instance(){
    if( _isSync == false ) {
      _isSync = true;
    }
    return FastorStateManagement._();
  }

  //------------------------------------------------------------------- setter

  void addState(State newState ) {
    _mapState[ newState.toString( ) ] = newState;
  }

   //------------------------------------------------------------------- getter

   ///get current page State
   State? getCurrentState()  {
    String keyMounted = "";

    //search
    _mapState.forEach((key, value) {
      key = keyMounted;
      bool result = value.mounted;
      if( result ) {
        return;
      }
   });
    return _mapState[ keyMounted ];
  }

  ///get current page context
   BuildContext? getCurrentContext()  {
    var myState = getCurrentState();
    if( myState == null ) return null;
     return myState.context;
   }


   /// check if the Flutter application is in the foreground
  bool isAppForeground(){
    State? myState = getCurrentState();
    return myState != null;
  }


}

==> fastor_app_ui_widget-0.0.67.tar.gz: lib/resource/state/FastorStateManagement.dart <==

import 'package:flutter/material.dart';

/// Manage the state of the application
///
/// Get current state just call method "FastorStateManagement.instance().getCurrentState()"
///  it's return state of map
///
/// To can use this library must to make all pages use class "PageTemplate"
class FastorStateManagement {

  //---------------------------------------------------------------- varaible

   static Map<String, State> _mapState = Map();


  //--------------------------------------------------------------- single tone

  FastorStateManagement._();

  static bool _isSync = false;

  ///single tone design pattern
  static FastorStateManagement instance(){
    if( _isSync == false ) {
      _isSync = true;
    }
    return FastorStateManagement._();
  }

  //------------------------------------------------------------------- setter

  void addState(State newState ) {
    _mapState[ newState.toString( ) ] = newState;
  }

   //------------------------------------------------------------------- getter

   ///get current page State
   State? getCurrentState()  {
    String keyMounted = "";

    //loop
    _mapState.forEach((keyLoop, value) {
      keyMounted = keyLoop;
      bool result = value.mounted;

      //log
      print( "getCurrentState()  - keyLoop: " + keyLoop + " /value: " + value.toString() + " /isMounted: " + result.toString() );

      if( result ) {
        return;
      }
   });

    //result
    var resultState  = _mapState[ keyMounted ];
    print( "getCurrentState()  - resultState: " + resultState.toString() + " /keyMounted: " + keyMounted.toString()  );
    return resultState;
  }

  ///get current page context
   BuildContext? getCurrentContext()  {
    var myState = getCurrentState();
    if( myState == null ) return null;
     return myState.context;
   }


   /// check if the Flutter application is in the foreground
  bool isAppForeground(){
    State? myState = getCurrentState();
    return myState != null;
  }


}
